@@ -3,8 +3,7 @@
 #  Apache2::WebApp::Plugin::Session::File - Plugin providing session storage
 #
 #  DESCRIPTION
-#  Store persistent data on the filesystem while maintaining a stateful
-#  session using web browser cookies.
+#  Store persistent data on the filesystem.
 #
 #  AUTHOR
 #  Marc S. Brooks <mbrooks@cpan.org>
@@ -23,7 +22,7 @@ use Apache::Session::Lock::File;
 use File::Path;
 use Params::Validate qw( :all );
 
-our $VERSION = 0.14;
+our $VERSION = 0.04;
 
 #~~~~~~~~~~~~~~~~~~~~~~~~~~[  OBJECT METHODS  ]~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
 
@@ -40,7 +39,7 @@ sub new {
 #----------------------------------------------------------------------------+
 # create( \%controller, $name, \%data )
 #
-# Create a new file based session and set a web browser cookie.
+# Create a new file based session.
 
 sub create {
     my ( $self, $c, $name, $data_ref )
@@ -51,9 +50,6 @@ sub create {
           { type => HASHREF }
           );
 
-    $self->error('Invalid session name')
-      unless ( $name =~ /^[\w-]{1,20}$/ );
-
     my $doc_root = $c->config->{apache_doc_root};
 
     my $tmp1 = "$doc_root/tmp/$name/session";
@@ -78,8 +74,8 @@ sub create {
         tie %session, 'Apache::Session::File', undef, {
             Directory     => $tmp1,
             LockDirectory => $tmp2,
-          };
-      };
+        };
+    };
 
     if ($@) {
         $self->error("Failed to create session: $@");
@@ -96,43 +92,39 @@ sub create {
     $c->plugin('Cookie')->set( $c, {
         name    => $name,
         value   => $id,
-        expires => $c->config->{session_expires} || '24h',
+        expires => '24h',
       });
 
     return $id;
 }
 
 #----------------------------------------------------------------------------+
-# get( \%controller, $arg )
+# get( \%controller, $name )
 #
-# Takes the cookie unique identifier or session id as arguments.  Returns
-# the session data as a hash reference.  
+# Return session data as a hash reference.
 
 sub get {
-    my ( $self, $c, $arg )
+    my ( $self, $c, $name )
       = validate_pos( @_,
           { type => OBJECT  },
           { type => HASHREF },
           { type => SCALAR  }
           );
 
-    $self->error('Malformed session identifier')
-      unless ( $arg =~ /^[\w-]{1,32}$/ );
-
     my $doc_root = $c->config->{apache_doc_root};
 
-    my $cookie = $c->plugin('Cookie')->get($arg);
+    my $cookie = $c->plugin('Cookie')->get($name);
 
-    my $id = ($cookie) ? $cookie : $arg;
+    my $session_id = ($cookie) ? $cookie : "null";
 
     my %session;
 
     eval {
-        tie %session, 'Apache::Session::File', $id, {
-            Directory     => "$doc_root/tmp/$arg/session",
-            LockDirectory => "$doc_root/tmp/$arg/lock",
-          };
-      };
+        tie %session, 'Apache::Session::File', $session_id, {
+            Directory     => "$doc_root/tmp/$name/session",
+            LockDirectory => "$doc_root/tmp/$name/lock",
+        };
+    };
 
     unless ($@) {
         my %values = %session;
@@ -146,54 +138,49 @@ sub get {
 }
 
 #----------------------------------------------------------------------------+
-# delete( \%controller, $arg )
+# delete( \%controller, $name )
 #
-# Takes the cookie unique identifier or session id as arguments.  Deletes
-# an existing session.
+# Delete an existing session.
 
 sub delete {
-    my ( $self, $c, $arg )
+    my ( $self, $c, $name )
       = validate_pos( @_,
           { type => OBJECT  },
           { type => HASHREF },
           { type => SCALAR  }
           );
 
-    $self->error('Malformed session identifier')
-      unless ( $arg =~ /^[\w-]{32}$/ );
-
     my $doc_root = $c->config->{apache_doc_root};
 
-    my $cookie = $c->plugin('Cookie')->get($arg);
+    my $cookie = $c->plugin('Cookie')->get($name);
 
-    my $id = ($cookie) ? $cookie : $arg;
+    my $id = ($cookie) ? $cookie : "null";
 
     my %session;
 
     eval {
         tie %session, 'Apache::Session::File', $id, {
-            Directory     => "$doc_root/tmp/$arg/session",
-            LockDirectory => "$doc_root/tmp/$arg/lock",
-          };
-      };
+            Directory     => "$doc_root/tmp/$name/session",
+            LockDirectory => "$doc_root/tmp/$name/lock",
+        };
+    };
 
     unless ($@) {
         tied(%session)->delete;
 
-        $c->plugin('Cookie')->delete( $c, $arg );
+        $c->plugin('Cookie')->delete( $c, $name );
     }
 
     return;
 }
 
 #----------------------------------------------------------------------------+
-# update( \%controller, $arg, \%data );
+# update( \%controller, $name, \%data );
 #
-# Takes the cookie unique identifier or session id as arguments.  Updates
-# existing session data.
+# Update existing session data.
 
 sub update {
-    my ( $self, $c, $arg, $data_ref )
+    my ( $self, $c, $name, $data_ref )
       = validate_pos( @_,
           { type => OBJECT  },
           { type => HASHREF },
@@ -201,23 +188,20 @@ sub update {
           { type => HASHREF }
           );
 
-    $self->error('Malformed session identifier')
-      unless ( $arg =~ /^[\w-]{32}$/ );
-
-    my $cookie = $c->plugin('Cookie')->get($arg);
-
-    my $id = ($cookie) ? $cookie : $arg;
-
     my $doc_root = $c->config->{apache_doc_root};
 
+    my $cookie = $c->plugin('Cookie')->get($name);
+
+    my $id = ($cookie) ? $cookie : "null";
+
     my %session;
 
     eval {
         tie %session, 'Apache::Session::File', $id, {
-            Directory     => "$doc_root/tmp/$arg/session",
-            LockDirectory => "$doc_root/tmp/$arg/lock",
-          };
-      };
+            Directory     => "$doc_root/tmp/$name/session",
+            LockDirectory => "$doc_root/tmp/$name/lock",
+        };
+    };
 
     if ($@) {
         $self->error("Failed to create session: $@");
@@ -232,25 +216,6 @@ sub update {
     return;
 }
 
-#----------------------------------------------------------------------------+
-# id( \%controller, $name )
-#
-# Return the cookie unique identifier for a given session.
-
-sub id {
-    my ( $self, $c, $name )
-      = validate_pos( @_,
-          { type => OBJECT  },
-          { type => HASHREF },
-          { type => SCALAR  }
-          );
-
-    $self->error('Malformed session identifier')
-      unless ( $name =~ /^[\w-]{32}$/ );
-
-    return $c->plugin('Cookie')->get($name);
-}
-
 #~~~~~~~~~~~~~~~~~~~~~~~~~~[  PRIVATE METHODS  ]~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
 
 #----------------------------------------------------------------------------+
@@ -281,8 +246,7 @@ Apache2::WebApp::Plugin::Session::File - Plugin providing session storage
 
 =head1 DESCRIPTION
 
-Store persistent data on the filesystem while maintaining a stateful session
-using web browser cookies.
+Store persistent data on the filesystem.
 
 =head1 PREREQUISITES
 
@@ -304,16 +268,16 @@ From source:
   $ tar xfz Apache2-WebApp-Plugin-Session-File-0.X.X.tar.gz
   $ perl MakeFile.PL PREFIX=~/path/to/custom/dir LIB=~/path/to/custom/lib
   $ make
-  $ make test
+  $ make test     <--- Make sure you do this before contacting me
   $ make install
 
 Perl one liner using CPAN.pm:
 
-  $ perl -MCPAN -e 'install Apache2::WebApp::Plugin::Session::File'
+  perl -MCPAN -e 'install Apache2::WebApp::Plugin::Session::File'
 
 Use of CPAN.pm in interactive mode:
 
-  $ perl -MCPAN -e shell
+  $> perl -MCPAN -e shell
   cpan> install Apache2::WebApp::Plugin::Session::File
   cpan> quit
 
@@ -326,7 +290,6 @@ Unless it already exists, add the following to your projects I<webapp.conf>
 
   [session]
   storage_type = file
-  expires = 1h
 
 =head1 OBJECT METHODS
 
@@ -347,6 +310,6 @@ Marc S. Brooks, E<lt>mbrooks@cpan.orgE<gt> - L<http://mbrooks.info>
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
-See L<http://dev.perl.org/licenses/artistic.html>
+See L<http://www.perl.com/perl/misc/Artistic.html>
 
 =cut
